==> gnucash-2.6.10-1-aarch64.pkg.tar.xz: usr/lib/gnucash/scm/ccache/2.0/gnucash/report/standard-reports/general-ledger.go <==
GOOF----LE-8-2.0      ] n 4        h      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  report	g  standard-reports		g  general-ledger	
	 	g  filenameS	f  general-ledger.scm	
g  set-current-module	
 	
 	g  call-with-deferred-observers	 	 	g  module-export!	 	 	g  current-module	 	 	g  gnc:make-general-ledger-report	 	g  process-use-modules	 	 	g  main	 	  	!g  
gnc-module	"! 	#" 	$g  gettext	%$ 	&% 	'g  gnc:module-load	(f  gnucash/report/report-system	)f  General Ledger	*g  
reportname	+f   2fe3b9833af044abb929a88d5a59620f	,g  xactrptguid	-f  Transaction Report	.g  xactrptname	/g  gnc:make-report	0g  +gnc:report-template-new-options/report-guid	1g  gnc:pagename-accounts	2g  gnc:option-set-value	3g  gnc:lookup-option	4f  Filter Type	5g  none	6f  Void Transactions	7g  
non-void-only	8g  for-each	9g  gnc:pagename-display	:g  'qof-book-use-split-action-for-num-field	;g  gnc-get-current-book	<f  Date	=f  Reconciled Date	>f  
Num/Action	?f  Trans Number	@f  Description	Af  Memo	Bf  Account Name	Cf  Use Full Account Name	Df  Account Code	Ef  Other Account Name	Ff  Use Full Other Account Name	Gf  Other Account Code	Hf  Shares	If  Price	Jf  Amount	Kg  double	Lf  Running Balance	Mf  Totals	Nf  
Sign Reverses	Og  credit-accounts	Pf  Num	Qg  gnc:pagename-general	Rf  Style	Sg  single	Tf  Sorting	Uf  Primary Key	Vg  account-code	Wf  Show Full Account Name	Xf  Show Account Code	Yf  Primary Subtotal	Zf  Primary Subtotal for Date Key	[f  Primary Sort Order	\g  ascend	]f  
Secondary Key	^g  register-order	_f  Secondary Subtotal	`f  Secondary Subtotal for Date Key	af  Secondary Sort Order	bg   general-ledger-options-generator	cg  (gnc:report-template-renderer/report-guid	dg  general-ledger-renderer	eg  gnc:define-report	fg  version	gg  name	hg  report-guid	if   2e22929e5c5b4b769f615a815ef0c20f	jg  	menu-path	kg  gnc:menuname-asset-liability	lg  options-generator	mg  rendererC 5  h8  -  ]4
5 4 >  "  G   4       h   D   ] 45 6   <       g  filenamef  general-ledger.scm
	 
 		
   C>  "  G  4  >  "  G  4# >  "  G  4& >  "  G  4'i(
>  "  G  )*R+,R-.R/,    h   w   ] 6o       g  filenamef  general-ledger.scm
	.
		/	 		
  g  nameg  gnc:make-general-ledger-report CR0,.12345678923     h(      ]  4L 56             g  l
		" g  section		" g  name			" g  value			"  g  filenamef  general-ledger.scm
	F			G	)	
	G	1		G			<		"	;	 		"   C:;<=>?@ABCDEFGHIJKLMNOPQRS23T    h       ]  4L 56         g  l
		 g  name			 g  value				  g  filenamef  general-ledger.scm
			 	%	 	-		 			<			9	!		<			;	 			   CUVWXYZ[\]^_`a 5      h  }  ]45 44 5>  "  G  44 	5
>  "  G  4 O 4
45 5$  u                  !"  "  k  #               !"  >  "  G  $44 %5&>  "  G  4' O () * + , - ./ 01 2 3 4/  
>  "  G   C   u      g  options
	 g  section		1 g  section	3	U g  section\~  g  filenamef  general-ledger.scm
	4
		6			6			?			;			<			@			<		!	@	.	&	;		3	A		6	;		9	<		A	B		C	<		E	B	4	J	;		V	E		`	I			c	I	2	i	I			m	I		o	K		s	K	
	u	L		y	L	
	{	M			M	
 	N	 	N	
 	O	 	O	
 	P	 	P	
 	Q	 	Q	
 	R	 	R	
 	S	 	S	
 	T	 	T	
 	U	 	U	
 	V	 	V	
 	W	 	W	
 	X	 	X	
 	Z	 	Z	 	Z	
 	[	 	[	
 	\	 	\	
 	]	 	]	% 	]	
 	J		 	`	 	`	
 	a	 	a	
 	b	 	b	
 	c	 	c	
 	d	 	d	
	e		e	
	f		f	
	g		g	
	h		h	
	i		i	
 	j	$	j	
&	k	*	k	
,	l	0	l	
2	n	4	n	7	n	
9	o	=	o	
?	p	C	p	
E	q	G	q	%J	q	
M	_		R	E	\	w	_	;	b	<	j	x	l	<	n	x	's	;		~	 	 	 	 	 	 	 	 	 	 	 	1 	 	 	& 	 	 	! 	 	 	 	 	3 	 	 	( 	 		~	 	
  g  nameg   general-ledger-options-generator CbRc,.      h      ]45 6        g  
report-obj
		  g  filenamef  general-ledger.scm
 
	 		 	 		  g  nameg  general-ledger-renderer CdReifg*ihijki lbimdi6 %      g  m
	
	$  g  filenamef  general-ledger.scm		
	%	 
 	!
 	"
 	#
 	%
 	%	 	%
 	'	 	'
 	(	 	(
	)		)
	.
P	4
 
     	" ) 	+ 1 7 
 	7
   C6 

==> gnucash-2.6.12-4-aarch64.pkg.tar.xz: usr/lib/gnucash/scm/ccache/2.0/gnucash/report/standard-reports/general-ledger.go <==
GOOF----LE-8-2.0      ] n 4        h	      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  report	g  standard-reports		g  general-ledger	
	 	g  filenameS	f  general-ledger.scm	
g  set-current-module	
 	
 	g  call-with-deferred-observers	 	 	g  module-export!	 	 	g  current-module	 	 	g  gnc:make-general-ledger-report	 	g  process-use-modules	 	 	g  main	 	  	!g  
gnc-module	"! 	#" 	$g  gettext	%$ 	&% 	'g  gnc:module-load	(f  gnucash/report/report-system	)f  General Ledger	*g  
reportname	+f   2fe3b9833af044abb929a88d5a59620f	,g  xactrptguid	-f  Transaction Report	.g  xactrptname	/g  gnc:make-report	0g  +gnc:report-template-new-options/report-guid	1g  gnc:pagename-accounts	2g  gnc:option-set-default-value	3g  gnc:lookup-option	4f  Filter Type	5g  none	6f  Void Transactions	7g  
non-void-only	8g  for-each	9g  gnc:pagename-display	:g  'qof-book-use-split-action-for-num-field	;g  gnc-get-current-book	<f  Date	=f  Reconciled Date	>f  
Num/Action	?f  Trans Number	@f  Description	Af  Memo	Bf  Account Name	Cf  Use Full Account Name	Df  Account Code	Ef  Other Account Name	Ff  Use Full Other Account Name	Gf  Other Account Code	Hf  Shares	If  Price	Jf  Amount	Kg  double	Lf  Running Balance	Mf  Totals	Nf  
Sign Reverses	Og  credit-accounts	Pf  Num	Qg  gnc:pagename-general	Rf  Style	Sg  single	Tf  Sorting	Uf  Primary Key	Vg  account-code	Wf  Show Full Account Name	Xf  Show Account Code	Yf  Primary Subtotal	Zf  Primary Subtotal for Date Key	[f  Primary Sort Order	\g  ascend	]f  
Secondary Key	^g  register-order	_f  Secondary Subtotal	`f  Secondary Subtotal for Date Key	af  Secondary Sort Order	bg   general-ledger-options-generator	cg  (gnc:report-template-renderer/report-guid	dg  general-ledger-renderer	eg  gnc:define-report	fg  version	gg  name	hg  report-guid	if   2e22929e5c5b4b769f615a815ef0c20f	jg  	menu-path	kg  gnc:menuname-asset-liability	lg  options-generator	mg  rendererC 5  h8  -  ]4
5 4 >  "  G   4       h   D   ] 45 6   <       g  filenamef  general-ledger.scm
	 
 		
   C>  "  G  4  >  "  G  4# >  "  G  4& >  "  G  4'i(
>  "  G  )*R+,R-.R/,    h   w   ] 6o       g  filenamef  general-ledger.scm
	.
		/	 		
  g  nameg  gnc:make-general-ledger-report CR0,.12345678923     h(      ]  4L 56             g  l
		" g  section		" g  name			" g  value			"  g  filenamef  general-ledger.scm
	F			G	)	
	G	1		G			<		"	;	 		"   C:;<=>?@ABCDEFGHIJKLMNOPQRS23T    h       ]  4L 56         g  l
		 g  name			 g  value				  g  filenamef  general-ledger.scm
			 	%	 	-		 			<			9	!		<			;	 			   CUVWXYZ[\]^_`a 5      h  }  ]45 44 5>  "  G  44 	5
>  "  G  4 O 4
45 5$  u                  !"  "  k  #               !"  >  "  G  $44 %5&>  "  G  4' O () * + , - ./ 01 2 3 4/  
>  "  G   C   u      g  options
	 g  section		1 g  section	3	U g  section\~  g  filenamef  general-ledger.scm
	4
		6			6			?			;			<			@			<		!	@	.	&	;		3	A		6	;		9	<		A	B		C	<		E	B	4	J	;		V	E		`	I			c	I	2	i	I			m	I		o	K		s	K	
	u	L		y	L	
	{	M			M	
 	N	 	N	
 	O	 	O	
 	P	 	P	
 	Q	 	Q	
 	R	 	R	
 	S	 	S	
 	T	 	T	
 	U	 	U	
 	V	 	V	
 	W	 	W	
 	X	 	X	
 	Z	 	Z	 	Z	
 	[	 	[	
 	\	 	\	
 	]	 	]	% 	]	
 	J		 	`	 	`	
 	a	 	a	
 	b	 	b	
 	c	 	c	
 	d	 	d	
	e		e	
	f		f	
	g		g	
	h		h	
	i		i	
 	j	$	j	
&	k	*	k	
,	l	0	l	
2	n	4	n	7	n	
9	o	=	o	
?	p	C	p	
E	q	G	q	%J	q	
M	_		R	E	\	w	_	;	b	<	j	x	l	<	n	x	's	;		~	 	 	 	 	 	 	 	 	 	 	 	1 	 	 	& 	 	 	! 	 	 	 	 	3 	 	 	( 	 		~	 	
  g  nameg   general-ledger-options-generator CbRc,.      h      ]45 6        g  
report-obj
		  g  filenamef  general-ledger.scm
 
	 		 	 		  g  nameg  general-ledger-renderer CdReifg*ihijki lbimdi6 %      g  m
	
	$  g  filenamef  general-ledger.scm		
	%	 
 	!
 	"
 	#
 	%
 	%	 	%
 	'	 	'
 	(	 	(
	)		)
	.
P	4
 
     	" ) 	+ 1 7 
 	7
   C6 
